==> petljadoc-1.4.3-py3-none-any.whl: petljadoc/runestone_ext/blockly/js/karelBlocks-i18n.sr-Latn.js <==
$.i18n().load({
    "sr-Latn": {
        "move_forward": "korak napred",
        "move_forward_tooltip": "Robot se pomera jedno polje u napred.",
        "move_back": "korak nazad",
        "move_back_tooltip": "Robot se pomera jedno polje u nazad.",
        "turn_left": "skreni levo",
        "turn_left_tooltip": "Robot se okreće na levo.",
        "turn_right": "skreni desno",
        "turn_right_tooltip": "Robot se okreće na desno.",
        "turn_around": "okreni polukružno",
        "turn_around_tooltip": "Robot se okreće na desno.",
        "pick_up": "uzmi",
        "pick_up_tooltip": "Robot uzima loptu sa polja na kome se nalazi.",
        "drop_off": "ostavi",
        "drop_off_tooltip": "Robot ostavlja loptu.",
        "can_move": "robot može napred",
        "can_move_tooltip": "Robot odgovara na pitanje da li može da napravi korak napred.",
        "balls_present": "postoji loptica",
        "balls_present_tooltip": "Robot odgovara na pitanje da li ima loptica na polju na kome se nalazi.",
        "has_balls": "robot ima lopticu",
        "has_balls_tooltip": "Da li robot ima loptice kod sebe.",
        "count_balls": "koliko loptica ima na polju",
        "count_balls_tooltip": "Robot odgovara na pitanje koliko loptica ima na polju na kome se nalazi.",
        "count_balls_on_hand": "koliko loptica ima kod robota",
        "count_balls_on_hand_tooltip": "Robot odgovara na pitanje koliko loptica ima kod sebe.",
        "karel_controls_whileUntil": "Ponavljaj dok %1",
        "robot_has_ball": "robot ima loptu",
        "balls_present_on_field": "loptice na polju",
        "robot_can_move_forward": "robot može napred",
        "variables_set": "Postavi %1 na %2",
        "number_prompt": "Pitaj ",
        "KarelCommands": "Naredbe robotu",
        "BeginnerKarelCommands": "Naredbe robotu",
        "KarelStraightLineCommands": "Naredbe robotu",
        "KarelBrain": "Pitaj robota",
        "K_Values": "Vrednosti",
        "K_Branching": "Grananje",
        "KarelBranching": "Grananje robot",
        "K_Vars": "Promenljive",
        "K_Loops": "Petlje",
        "KarelLoops": "Petlje robot",
        "K_Logic": "Logički operatori",
        "Arithmetic": "Aritmetika",
        "KarelSays": "Poruke robotu",
        "K_AskUser": "Pomozi robotu"
    }
})

==> petljadoc-1.4.5-py3-none-any.whl: petljadoc/runestone_ext/blockly/js/karelBlocks-i18n.sr-Latn.js <==
$.i18n().load({
    "sr-Latn": {
        "move_forward": "korak napred",
        "move_forward_tooltip": "Robot se pomera jedno polje u napred.",
        "move_back": "korak nazad",
        "move_back_tooltip": "Robot se pomera jedno polje u nazad.",
        "turn_left": "okreni se levo",
        "turn_left_tooltip": "Robot se okreće na levo.",
        "turn_right": "okreni se desno",
        "turn_right_tooltip": "Robot se okreće na desno.",
        "turn_around": "okreni polukružno",
        "turn_around_tooltip": "Robot se okreće na desno.",
        "pick_up": "uzmi",
        "pick_up_tooltip": "Robot uzima loptu sa polja na kome se nalazi.",
        "drop_off": "ostavi",
        "drop_off_tooltip": "Robot ostavlja loptu.",
        "can_move": "robot može napred",
        "can_move_tooltip": "Robot odgovara na pitanje da li može da napravi korak napred.",
        "balls_present": "postoji loptica",
        "balls_present_tooltip": "Robot odgovara na pitanje da li ima loptica na polju na kome se nalazi.",
        "has_balls": "robot ima lopticu",
        "has_balls_tooltip": "Da li robot ima loptice kod sebe.",
        "count_balls": "koliko loptica ima na polju",
        "count_balls_tooltip": "Robot odgovara na pitanje koliko loptica ima na polju na kome se nalazi.",
        "count_balls_on_hand": "koliko loptica ima kod robota",
        "count_balls_on_hand_tooltip": "Robot odgovara na pitanje koliko loptica ima kod sebe.",
        "karel_controls_whileUntil": "Ponavljaj dok %1",
        "robot_has_ball": "robot ima loptu",
        "balls_present_on_field": "loptice na polju",
        "robot_can_move_forward": "robot može napred",
        "variables_set": "Postavi %1 na %2",
        "number_prompt": "Pitaj ",
        "KarelCommands": "Naredbe robotu",
        "BeginnerKarelCommands": "Naredbe robotu",
        "KarelStraightLineCommands": "Naredbe robotu",
        "KarelBrain": "Pitaj robota",
        "K_Values": "Vrednosti",
        "K_Branching": "Grananje",
        "KarelBranching": "Grananje robot",
        "K_Vars": "Promenljive",
        "K_Loops": "Petlje",
        "KarelLoops": "Petlje robot",
        "K_Logic": "Logički operatori",
        "Arithmetic": "Aritmetika",
        "KarelSays": "Poruke robotu",
        "K_AskUser": "Pomozi robotu"
    }
})
